==> eks-1.182.0-sources.jar: software/amazon/awscdk/services/eks/CfnIdentityProviderConfigProps.java <==
package software.amazon.awscdk.services.eks;

/**
 * Properties for defining a `CfnIdentityProviderConfig`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.eks.*;
 * CfnIdentityProviderConfigProps cfnIdentityProviderConfigProps = CfnIdentityProviderConfigProps.builder()
 *         .clusterName("clusterName")
 *         .type("type")
 *         // the properties below are optional
 *         .identityProviderConfigName("identityProviderConfigName")
 *         .oidc(OidcIdentityProviderConfigProperty.builder()
 *                 .clientId("clientId")
 *                 .issuerUrl("issuerUrl")
 *                 // the properties below are optional
 *                 .groupsClaim("groupsClaim")
 *                 .groupsPrefix("groupsPrefix")
 *                 .requiredClaims(List.of(RequiredClaimProperty.builder()
 *                         .key("key")
 *                         .value("value")
 *                         .build()))
 *                 .usernameClaim("usernameClaim")
 *                 .usernamePrefix("usernamePrefix")
 *                 .build())
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.653Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.CfnIdentityProviderConfigProps")
@software.amazon.jsii.Jsii.Proxy(CfnIdentityProviderConfigProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnIdentityProviderConfigProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The cluster that the configuration is associated to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClusterName();

    /**
     * The type of the identity provider configuration.
     * <p>
     * The only type available is <code>oidc</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getType();

    /**
     * The name of the configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getIdentityProviderConfigName() {
        return null;
    }

    /**
     * An object representing an OpenID Connect (OIDC) identity provider configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOidc() {
        return null;
    }

    /**
     * The metadata to apply to the provider configuration to assist with categorization and organization.
     * <p>
     * Each tag consists of a key and an optional value. You define both.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnIdentityProviderConfigProps> {
        java.lang.String clusterName;
        java.lang.String type;
        java.lang.String identityProviderConfigName;
        java.lang.Object oidc;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getClusterName}
         * @param clusterName The cluster that the configuration is associated to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterName(java.lang.String clusterName) {
            this.clusterName = clusterName;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getType}
         * @param type The type of the identity provider configuration. This parameter is required.
         *             The only type available is <code>oidc</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder type(java.lang.String type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getIdentityProviderConfigName}
         * @param identityProviderConfigName The name of the configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identityProviderConfigName(java.lang.String identityProviderConfigName) {
            this.identityProviderConfigName = identityProviderConfigName;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getOidc}
         * @param oidc An object representing an OpenID Connect (OIDC) identity provider configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder oidc(software.amazon.awscdk.core.IResolvable oidc) {
            this.oidc = oidc;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getOidc}
         * @param oidc An object representing an OpenID Connect (OIDC) identity provider configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder oidc(software.amazon.awscdk.services.eks.CfnIdentityProviderConfig.OidcIdentityProviderConfigProperty oidc) {
            this.oidc = oidc;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getTags}
         * @param tags The metadata to apply to the provider configuration to assist with categorization and organization.
         *             Each tag consists of a key and an optional value. You define both.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnIdentityProviderConfigProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnIdentityProviderConfigProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnIdentityProviderConfigProps {
        private final java.lang.String clusterName;
        private final java.lang.String type;
        private final java.lang.String identityProviderConfigName;
        private final java.lang.Object oidc;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clusterName = software.amazon.jsii.Kernel.get(this, "clusterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.identityProviderConfigName = software.amazon.jsii.Kernel.get(this, "identityProviderConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.oidc = software.amazon.jsii.Kernel.get(this, "oidc", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clusterName = java.util.Objects.requireNonNull(builder.clusterName, "clusterName is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.identityProviderConfigName = builder.identityProviderConfigName;
            this.oidc = builder.oidc;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getClusterName() {
            return this.clusterName;
        }

        @Override
        public final java.lang.String getType() {
            return this.type;
        }

        @Override
        public final java.lang.String getIdentityProviderConfigName() {
            return this.identityProviderConfigName;
        }

        @Override
        public final java.lang.Object getOidc() {
            return this.oidc;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clusterName", om.valueToTree(this.getClusterName()));
            data.set("type", om.valueToTree(this.getType()));
            if (this.getIdentityProviderConfigName() != null) {
                data.set("identityProviderConfigName", om.valueToTree(this.getIdentityProviderConfigName()));
            }
            if (this.getOidc() != null) {
                data.set("oidc", om.valueToTree(this.getOidc()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-eks.CfnIdentityProviderConfigProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnIdentityProviderConfigProps.Jsii$Proxy that = (CfnIdentityProviderConfigProps.Jsii$Proxy) o;

            if (!clusterName.equals(that.clusterName)) return false;
            if (!type.equals(that.type)) return false;
            if (this.identityProviderConfigName != null ? !this.identityProviderConfigName.equals(that.identityProviderConfigName) : that.identityProviderConfigName != null) return false;
            if (this.oidc != null ? !this.oidc.equals(that.oidc) : that.oidc != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clusterName.hashCode();
            result = 31 * result + (this.type.hashCode());
            result = 31 * result + (this.identityProviderConfigName != null ? this.identityProviderConfigName.hashCode() : 0);
            result = 31 * result + (this.oidc != null ? this.oidc.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> eks-1.204.0-sources.jar: software/amazon/awscdk/services/eks/CfnIdentityProviderConfigProps.java <==
package software.amazon.awscdk.services.eks;

/**
 * Properties for defining a <code>CfnIdentityProviderConfig</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.eks.*;
 * CfnIdentityProviderConfigProps cfnIdentityProviderConfigProps = CfnIdentityProviderConfigProps.builder()
 *         .clusterName("clusterName")
 *         .type("type")
 *         // the properties below are optional
 *         .identityProviderConfigName("identityProviderConfigName")
 *         .oidc(OidcIdentityProviderConfigProperty.builder()
 *                 .clientId("clientId")
 *                 .issuerUrl("issuerUrl")
 *                 // the properties below are optional
 *                 .groupsClaim("groupsClaim")
 *                 .groupsPrefix("groupsPrefix")
 *                 .requiredClaims(List.of(RequiredClaimProperty.builder()
 *                         .key("key")
 *                         .value("value")
 *                         .build()))
 *                 .usernameClaim("usernameClaim")
 *                 .usernamePrefix("usernamePrefix")
 *                 .build())
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:46.537Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.CfnIdentityProviderConfigProps")
@software.amazon.jsii.Jsii.Proxy(CfnIdentityProviderConfigProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnIdentityProviderConfigProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The cluster that the configuration is associated to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClusterName();

    /**
     * The type of the identity provider configuration.
     * <p>
     * The only type available is <code>oidc</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getType();

    /**
     * The name of the configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getIdentityProviderConfigName() {
        return null;
    }

    /**
     * An object representing an OpenID Connect (OIDC) identity provider configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOidc() {
        return null;
    }

    /**
     * The metadata to apply to the provider configuration to assist with categorization and organization.
     * <p>
     * Each tag consists of a key and an optional value. You define both.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnIdentityProviderConfigProps> {
        java.lang.String clusterName;
        java.lang.String type;
        java.lang.String identityProviderConfigName;
        java.lang.Object oidc;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getClusterName}
         * @param clusterName The cluster that the configuration is associated to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterName(java.lang.String clusterName) {
            this.clusterName = clusterName;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getType}
         * @param type The type of the identity provider configuration. This parameter is required.
         *             The only type available is <code>oidc</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder type(java.lang.String type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getIdentityProviderConfigName}
         * @param identityProviderConfigName The name of the configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identityProviderConfigName(java.lang.String identityProviderConfigName) {
            this.identityProviderConfigName = identityProviderConfigName;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getOidc}
         * @param oidc An object representing an OpenID Connect (OIDC) identity provider configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder oidc(software.amazon.awscdk.core.IResolvable oidc) {
            this.oidc = oidc;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getOidc}
         * @param oidc An object representing an OpenID Connect (OIDC) identity provider configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder oidc(software.amazon.awscdk.services.eks.CfnIdentityProviderConfig.OidcIdentityProviderConfigProperty oidc) {
            this.oidc = oidc;
            return this;
        }

        /**
         * Sets the value of {@link CfnIdentityProviderConfigProps#getTags}
         * @param tags The metadata to apply to the provider configuration to assist with categorization and organization.
         *             Each tag consists of a key and an optional value. You define both.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnIdentityProviderConfigProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnIdentityProviderConfigProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnIdentityProviderConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnIdentityProviderConfigProps {
        private final java.lang.String clusterName;
        private final java.lang.String type;
        private final java.lang.String identityProviderConfigName;
        private final java.lang.Object oidc;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clusterName = software.amazon.jsii.Kernel.get(this, "clusterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.identityProviderConfigName = software.amazon.jsii.Kernel.get(this, "identityProviderConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.oidc = software.amazon.jsii.Kernel.get(this, "oidc", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clusterName = java.util.Objects.requireNonNull(builder.clusterName, "clusterName is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.identityProviderConfigName = builder.identityProviderConfigName;
            this.oidc = builder.oidc;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getClusterName() {
            return this.clusterName;
        }

        @Override
        public final java.lang.String getType() {
            return this.type;
        }

        @Override
        public final java.lang.String getIdentityProviderConfigName() {
            return this.identityProviderConfigName;
        }

        @Override
        public final java.lang.Object getOidc() {
            return this.oidc;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clusterName", om.valueToTree(this.getClusterName()));
            data.set("type", om.valueToTree(this.getType()));
            if (this.getIdentityProviderConfigName() != null) {
                data.set("identityProviderConfigName", om.valueToTree(this.getIdentityProviderConfigName()));
            }
            if (this.getOidc() != null) {
                data.set("oidc", om.valueToTree(this.getOidc()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-eks.CfnIdentityProviderConfigProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnIdentityProviderConfigProps.Jsii$Proxy that = (CfnIdentityProviderConfigProps.Jsii$Proxy) o;

            if (!clusterName.equals(that.clusterName)) return false;
            if (!type.equals(that.type)) return false;
            if (this.identityProviderConfigName != null ? !this.identityProviderConfigName.equals(that.identityProviderConfigName) : that.identityProviderConfigName != null) return false;
            if (this.oidc != null ? !this.oidc.equals(that.oidc) : that.oidc != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clusterName.hashCode();
            result = 31 * result + (this.type.hashCode());
            result = 31 * result + (this.identityProviderConfigName != null ? this.identityProviderConfigName.hashCode() : 0);
            result = 31 * result + (this.oidc != null ? this.oidc.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
